==> ej2-vue-maps-16.3.33.tgz: package/README.md <==
# ej2-vue-maps

The maps control is used to visualize the geographical data and represent the statistical data of a particular geographical area on earth with user interactivity, and provides various customizing options. 

![Maps](https://ej2.syncfusion.com/products/images/maps/readme.gif)

> Maps is part of Syncfusion Essential JS 2 commercial program. License is available in two models Community and Paid. Please refer the license file for more information. License can be obtained by registering at [https://www.syncfusion.com/downloads/essential-js2](https://www.syncfusion.com/downloads/essential-js2?utm_source=npm&utm_campaign=maps)

## Setup

To install Maps and its dependent packages, use the following command

```sh
npm install @syncfusion/ej2-maps
```

## Resources

* [Getting Started](https://ej2.syncfusion.com/vue/documentation/maps/getting-started.html)
* [View Online Demos](https://ej2.syncfusion.com/vue/demos/#/material/maps/default.html)
* [Product Page](https://www.syncfusion.com/vue-ui-components/maps)

## Supported Frameworks

Maps component is also offered in following list of frameworks.

1. [Angular](https://www.npmjs.com/package/@syncfusion/ej2-ng-maps?utm_source=npm&utm_campaign=maps)
2. [React](https://www.npmjs.com/package/@syncfusion/ej2-react-maps?utm_source=npm&utm_campaign=maps)
3. [Vue.js](https://www.npmjs.com/package/@syncfusion/ej2-vue-maps?utm_source=npm&utm_campaign=maps)
4. [ASP.NET Core](https://aspdotnetcore.syncfusion.com/Maps/Default#/material)
5. [ASP.NET MVC](https://aspnetmvc.syncfusion.com/Maps/Default#/material)
6. [JavaScript (ES5)](https://www.syncfusion.com/javascript-ui-controls/maps)

## Use case samples

* Heat map ([Live Demo](https://ej2.syncfusion.com/vue/demos/#/material/maps/heatmap.html))
* Flight routes ([Live Demo](https://ej2.syncfusion.com/vue/demos/#/material/maps/curvedlines.html))
* Bus seat booking ([Live Demo](https://ej2.syncfusion.com/vue/demos/#/material/maps/seatSelection.html))

## Key Features

* [**Data sources**](https://ej2.syncfusion.com/vue/demos/#/material/maps/default.html) - Binds the maps component with an array of JSON objects or DataManager.
* [**Projection**](https://ej2.syncfusion.com/vue/demos/#/material/maps/projection.html) - Maps can be rendered in eight types of projections.
* [**Drill-down**](https://ej2.syncfusion.com/vue/demos/#/material/maps/drilldown.html) - Provides drill-down option to have a closer look at the lower level of a hierarchy.
* [**Marker**](https://ej2.syncfusion.com/vue/demos/#/material/maps/marker.html) - Provides marker support to mark a specific place of interest in the map.
* [**Data label**](https://ej2.syncfusion.com/vue/demos/#/material/maps/datalabel.html) - Provides additional information about the shapes.
* [**Bubble**](https://ej2.syncfusion.com/vue/demos/#/material/maps/bubble.html) - Represents the underlying data values of the shapes.
* [**Navigation line**](https://ej2.syncfusion.com/vue/demos/#/material/maps/lineapeninsular.html) - Denotes the path between two locations.
* [**Color mapping**](https://ej2.syncfusion.com/vue/demos/#/material/maps/datalabel.html) - Applies colors to the shapes based on various conditions. Maps supports two types of color mapping: range color mapping and equal color mapping.
* [**Legend**](https://ej2.syncfusion.com/vue/demos/#/material/maps/legend.html) - Denotes the color mapping categories.
* [**Annotation**](https://ej2.syncfusion.com/vue/demos/#/material/maps/annotation.html) - Uses any custom HTML element as annotation and place it anywhere on the maps.
* [**Selection and Highlight**](https://ej2.syncfusion.com/vue/demos/#/material/maps/selection.html) - Supports selecting or highlighting the shapes to bring center of attraction.
* [**Zooming and Panning**](https://ej2.syncfusion.com/vue/demos/#/material/maps/zooming.html) - Allows to zoom in, out, and pan the map to show in-depth information.
* [**Tooltip**](https://ej2.syncfusion.com/vue/demos/#/material/maps/tooltip.html) - Provides additonal information about the shapes on mouse hover.
* [**Print and Export**](https://ej2.syncfusion.com/vue/demos/#/material/maps/print.html) - Provides options to print and export the rendered maps for future use.

## Support

Product support is available for through following mediums.

* Creating incident in Syncfusion [Direct-trac](https://www.syncfusion.com/support/directtrac/incidents?utm_source=npm&utm_campaign=maps) support system or [Community forum](https://www.syncfusion.com/forums/essential-js2?utm_source=npm&utm_campaign=maps).
* New [GitHub issues](https://github.com/syncfusion/ej2-vue-ui-components/issues).
* Ask your query in Stack Overflow with tag `syncfusion`, `ej2`.

## License

Check the license detail [here](https://github.com/syncfusion/ej2-vue-ui-components/blob/master/license?utm_source=npm&utm_campaign=maps).

## Changelog

Check the changelog [here](https://github.com/syncfusion/ej2-vue-ui-components/blob/master/components/maps/CHANGELOG.mdutm_source=npm&utm_campaign=maps)

© Copyright 2018 Syncfusion, Inc. All Rights Reserved. The Syncfusion Essential Studio license and copyright applies to this distribution.

==> ej2-vue-maps-16.4.42.tgz: package/README.md <==
# ej2-vue-maps

The maps control is used to visualize the geographical data and represent the statistical data of a particular geographical area on earth with user interactivity, and provides various customizing options. 

![Maps](https://ej2.syncfusion.com/products/images/maps/readme.gif)

> Maps is part of Syncfusion Essential JS 2 commercial program. License is available in two models Community and Paid. Please refer the license file for more information. License can be obtained by registering at [https://www.syncfusion.com/downloads/essential-js2](https://www.syncfusion.com/downloads/essential-js2?utm_source=npm&utm_campaign=maps)

## Setup

To install Maps and its dependent packages, use the following command

```sh
npm install @syncfusion/ej2-maps
```

## Resources

* [Getting Started](https://ej2.syncfusion.com/vue/documentation/maps/getting-started.html)
* [View Online Demos](https://ej2.syncfusion.com/vue/demos/#/material/maps/default.html)
* [Product Page](https://www.syncfusion.com/products/javascript/maps)

## Supported Frameworks

Maps component is also offered in following list of frameworks.

1. [Angular](https://www.npmjs.com/package/@syncfusion/ej2-ng-maps?utm_source=npm&utm_campaign=maps)
2. [React](https://www.npmjs.com/package/@syncfusion/ej2-react-maps?utm_source=npm&utm_campaign=maps)
3. [Vue.js](https://www.npmjs.com/package/@syncfusion/ej2-vue-maps?utm_source=npm&utm_campaign=maps)
4. [ASP.NET Core](https://aspdotnetcore.syncfusion.com/Maps/Default#/material)
5. [ASP.NET MVC](https://aspnetmvc.syncfusion.com/Maps/Default#/material)
6. [JavaScript (ES5)](https://www.syncfusion.com/products/javascript/maps)

## Use case samples

* Heat map ([Live Demo](https://ej2.syncfusion.com/vue/demos/#/material/maps/heatmap.html))
* Flight routes ([Live Demo](https://ej2.syncfusion.com/vue/demos/#/material/maps/curvedlines.html))
* Bus seat booking ([Live Demo](https://ej2.syncfusion.com/vue/demos/#/material/maps/seatSelection.html))

## Key Features

* [**Data sources**](https://ej2.syncfusion.com/vue/demos/#/material/maps/default.html) - Binds the maps component with an array of JSON objects or DataManager.
* [**Projection**](https://ej2.syncfusion.com/vue/demos/#/material/maps/projection.html) - Maps can be rendered in eight types of projections.
* [**Drill-down**](https://ej2.syncfusion.com/vue/demos/#/material/maps/drilldown.html) - Provides drill-down option to have a closer look at the lower level of a hierarchy.
* [**Marker**](https://ej2.syncfusion.com/vue/demos/#/material/maps/marker.html) - Provides marker support to mark a specific place of interest in the map.
* [**Data label**](https://ej2.syncfusion.com/vue/demos/#/material/maps/datalabel.html) - Provides additional information about the shapes.
* [**Bubble**](https://ej2.syncfusion.com/vue/demos/#/material/maps/bubble.html) - Represents the underlying data values of the shapes.
* [**Navigation line**](https://ej2.syncfusion.com/vue/demos/#/material/maps/lineapeninsular.html) - Denotes the path between two locations.
* [**Color mapping**](https://ej2.syncfusion.com/vue/demos/#/material/maps/datalabel.html) - Applies colors to the shapes based on various conditions. Maps supports two types of color mapping: range color mapping and equal color mapping.
* [**Legend**](https://ej2.syncfusion.com/vue/demos/#/material/maps/legend.html) - Denotes the color mapping categories.
* [**Annotation**](https://ej2.syncfusion.com/vue/demos/#/material/maps/annotation.html) - Uses any custom HTML element as annotation and place it anywhere on the maps.
* [**Selection and Highlight**](https://ej2.syncfusion.com/vue/demos/#/material/maps/selection.html) - Supports selecting or highlighting the shapes to bring center of attraction.
* [**Zooming and Panning**](https://ej2.syncfusion.com/vue/demos/#/material/maps/zooming.html) - Allows to zoom in, out, and pan the map to show in-depth information.
* [**Tooltip**](https://ej2.syncfusion.com/vue/demos/#/material/maps/tooltip.html) - Provides additonal information about the shapes on mouse hover.
* [**Print and Export**](https://ej2.syncfusion.com/vue/demos/#/material/maps/print.html) - Provides options to print and export the rendered maps for future use.

## Support

Product support is available for through following mediums.

* Creating incident in Syncfusion [Direct-trac](https://www.syncfusion.com/support/directtrac/incidents?utm_source=npm&utm_campaign=maps) support system or [Community forum](https://www.syncfusion.com/forums/essential-js2?utm_source=npm&utm_campaign=maps).
* New [GitHub issues](https://github.com/syncfusion/ej2-vue-ui-components/issues).
* Ask your query in Stack Overflow with tag `syncfusion`, `ej2`.

## License

Check the license detail [here](https://github.com/syncfusion/ej2-vue-ui-components/blob/master/license?utm_source=npm&utm_campaign=maps).

## Changelog

Check the changelog [here](https://github.com/syncfusion/ej2-vue-ui-components/blob/master/components/maps/CHANGELOG.mdutm_source=npm&utm_campaign=maps)

© Copyright 2018 Syncfusion, Inc. All Rights Reserved. The Syncfusion Essential Studio license and copyright applies to this distribution.
